==> onyxproject-0.1.4.tar.gz: onyxproject-0.1.4/onyx/core/__init__.py <==
#!/usr/bin/env python
# encoding: utf-8
__version__ = '0.1.4'
import os
from os.path import exists
import sys
import site
import platform
reload(sys)
sys.setdefaultencoding('utf-8')


from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from flask_login import LoginManager , login_user , login_required
from flask import flash , request , render_template , url_for , redirect
from flask_mail import Mail, Message


template_folder = os.path.dirname(os.path.dirname(__file__)) + '/templates'
static_folder = os.path.dirname(os.path.dirname(__file__)) + '/static'


core = Flask('app', template_folder=template_folder , static_folder=static_folder)
core.config.from_object('onyx.bddconfig')
db = SQLAlchemy(core)
from models import *

if exists(site.getsitepackages()[0] + "/onyx/core/install") == True:
	print "Installation en cour :"
	if platform.system() == "Linux":
		os.system("sudo apt-get install moc mplayer python-dev")
		try:
			from migrate.versioning import api
			from onyx.bddconfig import SQLALCHEMY_DATABASE_URI
			from onyx.bddconfig import SQLALCHEMY_MIGRATE_REPO
			from onyx.core import db
			import os.path
			db.create_all()
			if not os.path.exists(SQLALCHEMY_MIGRATE_REPO):
			    api.create(SQLALCHEMY_MIGRATE_REPO, 'database repository')
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
			else:
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO,
			                        api.version(SQLALCHEMY_MIGRATE_REPO))
			print "Base de donnée initialisée"
		except:
			print "Base de donnée déjà initialisée"
	else:
		try:
			from migrate.versioning import api
			from onyx.bddconfig import SQLALCHEMY_DATABASE_URI
			from onyx.bddconfig import SQLALCHEMY_MIGRATE_REPO
			from onyx.core import db
			import os.path
			db.create_all()
			if not os.path.exists(SQLALCHEMY_MIGRATE_REPO):
			    api.create(SQLALCHEMY_MIGRATE_REPO, 'database repository')
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
			else:
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO,
			                        api.version(SQLALCHEMY_MIGRATE_REPO))
			print "Base de donnée initialisée"
		except:
			print "Base de donnée déjà initialisée"
	from install import *
else:
	from controllers import *


core.config['SECRET_KEY'] = 'onyx'

#if platform.system() == 'Linux':
	#from onyx.core.assets import getAlarm
	#getAlarm.setAlarm()

==> onyxproject-0.1.5.tar.gz: onyxproject-0.1.5/onyx/core/__init__.py <==
#!/usr/bin/env python
# encoding: utf-8
__version__ = '0.1.4'
import os
from os.path import exists
import sys
import site
import platform
reload(sys)
sys.setdefaultencoding('utf-8')

import onyx
from flask import Flask
from flask_sqlalchemy import SQLAlchemy
from flask_login import LoginManager , login_user , login_required
from flask import flash , request , render_template , url_for , redirect
from flask_mail import Mail, Message


template_folder = os.path.dirname(os.path.dirname(__file__)) + '/templates'
static_folder = os.path.dirname(os.path.dirname(__file__)) + '/static'


core = Flask('app', template_folder=template_folder , static_folder=static_folder)
core.config.from_object('onyx.bddconfig')
db = SQLAlchemy(core)
from models import *

if exists(onyx.__path__ + "/core/install") == True:
	print "Installation en cour :"
	print onyx.__path__
	if platform.system() == "Linux":
		os.system("sudo apt-get install moc mplayer python-dev")
		try:
			from migrate.versioning import api
			from onyx.bddconfig import SQLALCHEMY_DATABASE_URI
			from onyx.bddconfig import SQLALCHEMY_MIGRATE_REPO
			from onyx.core import db
			import os.path
			db.create_all()
			if not os.path.exists(SQLALCHEMY_MIGRATE_REPO):
			    api.create(SQLALCHEMY_MIGRATE_REPO, 'database repository')
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
			else:
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO,
			                        api.version(SQLALCHEMY_MIGRATE_REPO))
			print "Base de donnée initialisée"
		except:
			print "Base de donnée déjà initialisée"
	else:
		try:
			from migrate.versioning import api
			from onyx.bddconfig import SQLALCHEMY_DATABASE_URI
			from onyx.bddconfig import SQLALCHEMY_MIGRATE_REPO
			from onyx.core import db
			import os.path
			db.create_all()
			if not os.path.exists(SQLALCHEMY_MIGRATE_REPO):
			    api.create(SQLALCHEMY_MIGRATE_REPO, 'database repository')
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
			else:
			    api.version_control(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO,
			                        api.version(SQLALCHEMY_MIGRATE_REPO))
			print "Base de donnée initialisée"
		except:
			print "Base de donnée déjà initialisée"
	from install import *
else:
	from controllers import *


core.config['SECRET_KEY'] = 'onyx'

#if platform.system() == 'Linux':
	#from onyx.core.assets import getAlarm
	#getAlarm.setAlarm()
